"""Typed Pydantic models for Airbyte connectors."""

from airbyte_connector_models.connectors._internal.base_record import BaseRecordModel

__version__ = "0.1.0"

__all__ = [
    "BaseRecordModel",
]
